@@ -14,7 +14,21 @@ from epsilon.scripts import benchmark
 from epsilon import juice
 
 
+try:
+    filepath.FilePath('/proc/diskstats').open().close()
+    filepath.FilePath('/proc/self/mounts').open().close()
+except IOError:
+    hasProc = False
+else:
+    hasProc = True
+
+
+
 class DiskstatTestCase(unittest.TestCase):
+    if not hasProc:
+        skip = 'epsilon.benchmark requires access to /proc'
+
+
     def testDiskLineParser(self):
         """
         Test the parsing of a single line into a single diststat instance.
@@ -236,19 +250,18 @@ class ReporterTestCase(unittest.TestCase):
             os.path.getsize(path) + os.path.getsize(os.path.join(path, 'foo')))
 
 
-    def testGetSizeBrokenSymlink(self):
+    def test_getOneSizeBrokenSymlink(self):
         """
-        Test that a broken symlink inside a directory passed to getSize doesn't
+        Test that a broken symlink inside a directory passed to getOneSize doesn't
         cause it to freak out.
         """
-        path = self.mktemp()
-        os.makedirs(path)
-        presize = benchmark.getSize(filepath.FilePath(path))
-        print presize
-        os.symlink('abcdefg', os.path.join(path, 'foo'))
+        path = filepath.FilePath(self.mktemp())
+        path.makedirs()
+        link = path.child('foo')
+        os.symlink('abcdefg', link.path)
         self.assertEquals(
-            benchmark.getSize(filepath.FilePath(path)),
-            presize + len('abcdefg'))
+            benchmark.getOneSize(link),
+            len('abcdefg'))
 
 
 
@@ -394,6 +407,10 @@ class BasicProcessTestCase(SpawnMixin, unittest.TestCase):
 
 
 class SnapshotTestCase(unittest.TestCase):
+    if not hasProc:
+        skip = 'epsilon.benchmark requires access to /proc'
+
+
     def testStart(self):
         c = benchmark.Change()
         c.start(filepath.FilePath('.'), 'hda', 'hda1')
@@ -408,6 +425,9 @@ class SnapshotTestCase(unittest.TestCase):
 
 
 class BenchmarkProcessTestCase(SpawnMixin, unittest.TestCase):
+    if not hasProc:
+        skip = 'epsilon.benchmark requires access to /proc'
+
 
     processProtocol = benchmark.BenchmarkProcess
 
